@@ -353,7 +353,8 @@ def general_objs(request, Obj, ObjForm, fields=(), query_dict={}, query_term='',
 
 
 def general_obj(request, Obj, ObjForm, general_obj_id, fields=(), \
-        template=False, html_scripts=False, translations={}, *args, **kwargs):
+        template=False, html_scripts=False, translations={}, \
+        additional_buttons='', *args, **kwargs):
     """General view for displaying a detailed view of an object"""
     if not template:
         template = 'generalobj.html'
@@ -363,6 +364,7 @@ def general_obj(request, Obj, ObjForm, general_obj_id, fields=(), \
     obj = get_object_or_404(Obj, id=general_obj_id)
     ret_dic['obj'] = obj
     ret_dic['class_name'] = Obj._meta.object_name
+    ret_dic['additional_buttons'] = additional_buttons
     if not fields:
         fields = [field.name for field in obj._meta.fields]
     if fields:
